@@ -72,4 +72,12 @@ test_that("time zones are preserved", {
     expect_that(get_tz(both$x)[1], equals(tz), label = tz)
   }
 
+})
+
+test_that("arrays are ok", {
+  df <- data.frame(x = 1)
+  df$x <- array(1, 1)
+
+  df2 <- rbind.fill(df, df)
+  expect_that(df2$x, is_equivalent_to(rbind(df, df)$x))
 })
\ No newline at end of file
